var searchData=
[
  ['qnan_0',['qNan',['../classopenvdb_1_1v12__1_1_1math_1_1internal_1_1half.html#a210eb05b9cb5e702cd3b98f24eea0a78',1,'openvdb::v12_1::math::internal::half']]],
  ['quad_1',['quad',['../classopenvdb_1_1v12__1_1_1tools_1_1PolygonPool.html#a55858b7ea4e93c3db5ef8d448f9c4052',1,'openvdb::v12_1::tools::PolygonPool::quad(size_t n)'],['../classopenvdb_1_1v12__1_1_1tools_1_1PolygonPool.html#ad0b06d7be794a58f4aa1a0c2db3d439a',1,'openvdb::v12_1::tools::PolygonPool::quad(size_t n) const']]],
  ['quadandtriangledataadapter_2',['QuadAndTriangleDataAdapter',['../structopenvdb_1_1v12__1_1_1tools_1_1QuadAndTriangleDataAdapter.html',1,'QuadAndTriangleDataAdapter&lt; PointType, PolygonType &gt;'],['../structopenvdb_1_1v12__1_1_1tools_1_1QuadAndTriangleDataAdapter.html#a77132b44ec7d41809377d4bd855ba459',1,'openvdb::v12_1::tools::QuadAndTriangleDataAdapter::QuadAndTriangleDataAdapter(const std::vector&lt; PointType &gt; &amp;points, const std::vector&lt; PolygonType &gt; &amp;polygons)'],['../structopenvdb_1_1v12__1_1_1tools_1_1QuadAndTriangleDataAdapter.html#abed5272d67f448d98ffb5530a78c8040',1,'openvdb::v12_1::tools::QuadAndTriangleDataAdapter::QuadAndTriangleDataAdapter(const PointType *pointArray, size_t pointArraySize, const PolygonType *polygonArray, size_t polygonArraySize)']]],
  ['quadflags_3',['quadFlags',['../classopenvdb_1_1v12__1_1_1tools_1_1PolygonPool.html#af9c07e03219767aa6bc426ac4f0bbfd2',1,'openvdb::v12_1::tools::PolygonPool::quadFlags(size_t n)'],['../classopenvdb_1_1v12__1_1_1tools_1_1PolygonPool.html#a4ff27555ca6d775dc073c4a6d7b9dfec',1,'openvdb::v12_1::tools::PolygonPool::quadFlags(size_t n) const']]],
  ['quadraticsample_4',['quadraticSample',['../namespaceopenvdb_1_1v12__1_1_1points.html#ad694b6c2cdbcd760f327fe3fb36ae936',1,'openvdb::v12_1::points']]],
  ['quadraticsampler_5',['QuadraticSampler',['../structopenvdb_1_1v12__1_1_1tools_1_1QuadraticSampler.html',1,'openvdb::v12_1::tools']]],
  ['quantizedunitvec_6',['QuantizedUnitVec',['../classopenvdb_1_1v12__1_1_1math_1_1QuantizedUnitVec.html',1,'openvdb::v12_1::math']]],
  ['quantizedunitvec_2eh_7',['QuantizedUnitVec.h',['../QuantizedUnitVec_8h.html',1,'']]],
  ['quat_8',['Quat',['../classopenvdb_1_1v12__1_1_1math_1_1Quat.html',1,'Quat&lt; T &gt;'],['../classopenvdb_1_1v12__1_1_1math_1_1Quat.html#a5e8566bdc976db32805a58f190395eb0',1,'openvdb::v12_1::math::Quat::Quat()=default'],['../classopenvdb_1_1v12__1_1_1math_1_1Quat.html#aa2de4bf209b4613bb9a148cd10d17e56',1,'openvdb::v12_1::math::Quat::Quat(T x, T y, T z, T w)'],['../classopenvdb_1_1v12__1_1_1math_1_1Quat.html#a55f983267a298932049687603f73e19e',1,'openvdb::v12_1::math::Quat::Quat(T *a)'],['../classopenvdb_1_1v12__1_1_1math_1_1Quat.html#a644f03043ec359f8149f2a590ed19ff4',1,'openvdb::v12_1::math::Quat::Quat(const Vec3&lt; T &gt; &amp;axis, T angle)'],['../classopenvdb_1_1v12__1_1_1math_1_1Quat.html#a5ba702efec452553e1de05edfaae411d',1,'openvdb::v12_1::math::Quat::Quat(math::Axis axis, T angle)'],['../classopenvdb_1_1v12__1_1_1math_1_1Quat.html#a87e9a26f7bb5e7579fbee0453a2c2c42',1,'openvdb::v12_1::math::Quat::Quat(const Mat3&lt; T1 &gt; &amp;rot)']]],
  ['quat_2eh_9',['Quat.h',['../Quat_8h.html',1,'']]],
  ['quat_3c_20double_20_3e_10',['Quat&lt; double &gt;',['../classopenvdb_1_1v12__1_1_1math_1_1Quat.html',1,'openvdb::v12_1::math']]],
  ['quat_3c_20float_20_3e_11',['Quat&lt; float &gt;',['../classopenvdb_1_1v12__1_1_1math_1_1Quat.html',1,'openvdb::v12_1::math']]],
  ['quat_3c_20real_20_3e_12',['Quat&lt; Real &gt;',['../classopenvdb_1_1v12__1_1_1math_1_1Quat.html',1,'openvdb::v12_1::math']]],
  ['quat_3c_20subt_20_3e_13',['Quat&lt; SubT &gt;',['../classopenvdb_1_1v12__1_1_1math_1_1Quat.html',1,'openvdb::v12_1::math']]],
  ['quatattributetypes_14',['QuatAttributeTypes',['../namespaceopenvdb_1_1v12__1.html#a594001495381ca0e2aa556b45ad5fb36',1,'openvdb::v12_1']]],
  ['quatd_15',['QUATD',['../namespaceopenvdb_1_1v12__1_1_1ax_1_1ast_1_1tokens.html#ae857f6f64ff599622ca80279d28242b7ade3ba364907e4830354690aac52fbeee',1,'openvdb::v12_1::ax::ast::tokens']]],
  ['quatd_16',['Quatd',['../namespaceopenvdb_1_1v12__1_1_1math.html#acf69cf7c7e5473d4533bd7c513a57580',1,'openvdb::v12_1::math::Quatd'],['../namespaceopenvdb_1_1v12__1.html#acf69cf7c7e5473d4533bd7c513a57580',1,'openvdb::v12_1::Quatd']]],
  ['quatf_17',['QUATF',['../namespaceopenvdb_1_1v12__1_1_1ax_1_1ast_1_1tokens.html#ae857f6f64ff599622ca80279d28242b7ac793a0dcc982274c5ae0bbaf6e02adac',1,'openvdb::v12_1::ax::ast::tokens']]],
  ['quatr_18',['QuatR',['../namespaceopenvdb_1_1v12__1.html#af0a17c7cdf98a4f9ede1535576f7ac38',1,'openvdb::v12_1']]],
  ['quats_19',['Quats',['../namespaceopenvdb_1_1v12__1_1_1math.html#ae5d4fcba2b5d70080b3938b662e2914b',1,'openvdb::v12_1::math::Quats'],['../namespaceopenvdb_1_1v12__1.html#ae5d4fcba2b5d70080b3938b662e2914b',1,'openvdb::v12_1::Quats']]],
  ['quatslist_20',['QuatsList',['../classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFracture.html#a5bed47f213d43c60b54b5d1044f9973d',1,'openvdb::v12_1::tools::LevelSetFracture']]],
  ['quattraits_21',['QuatTraits',['../structopenvdb_1_1v12__1_1_1QuatTraits.html',1,'openvdb::v12_1']]],
  ['quattraits_3c_20t_2c_20false_20_3e_22',['QuatTraits&lt; T, false &gt;',['../structopenvdb_1_1v12__1_1_1QuatTraits_3_01T_00_01false_01_4.html',1,'openvdb::v12_1']]],
  ['question_23',['QUESTION',['../axparser_8h.html#a4fb17c3afc02be01e847b79146e4a6e6ad126f509c35e1661274f8b72693c7848',1,'axparser.h']]],
  ['questions_24',['Frequently Asked Questions',['../faq.html',1,'index']]],
  ['queue_25',['Queue',['../classopenvdb_1_1v12__1_1_1io_1_1Queue.html',1,'Queue'],['../classopenvdb_1_1v12__1_1_1io_1_1Queue.html#ad9627bf962cb5c9e2d3e9b50e29f7f90',1,'openvdb::v12_1::io::Queue::Queue()']]],
  ['queue_2eh_26',['Queue.h',['../Queue_8h.html',1,'']]],
  ['quiet_5fnan_27',['quiet_NaN',['../classstd_1_1numeric__limits_3_01openvdb_1_1math_1_1internal_1_1half_01_4.html#a2e7f841971282f959b98e581141c0464',1,'std::numeric_limits&lt; openvdb::math::internal::half &gt;']]]
];
